@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1999-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1999-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 * ӥåȥޥåײùؿ                                                        *
 *                                                                             *
 ******************************************************************************/
-#include <string.h>
 #include "bitmap.h"
 
 
@@ -205,7 +204,7 @@ void bitmap_make_palette(const gint count,RgbQuad *rgb,
 	guint max;
 	PaletteTableList p,ptl[256];
 
-	memset(ptl,0,count*sizeof(PaletteTableList));
+	g_memset(ptl,0,count*sizeof(PaletteTableList));
 	ptl[0].blue_max=ptl[0].green_max=ptl[0].red_max=31;
 	for (i=0;i<32;i++)
 		for (j=0;j<32;j++)
@@ -226,7 +225,7 @@ void bitmap_make_palette(const gint count,RgbQuad *rgb,
 		if (max==0)
 			break;
 		p=ptl[k];
-		memmove(&ptl[k],&ptl[k+1],(i-k)*sizeof(PaletteTableList));
+		g_memmove(&ptl[k],&ptl[k+1],(i-k)*sizeof(PaletteTableList));
 		divide_palette_count(&p,&ptl[i-1],&ptl[i],table);
 	}
 	while (i<count) {
@@ -251,7 +250,7 @@ void bitmap_make_palette(const gint count,RgbQuad *rgb,
 		if (max==0)
 			break;
 		p=ptl[k];
-		memcpy(&ptl[k],&ptl[k+1],(i-k)*sizeof(PaletteTableList));
+		g_memmove(&ptl[k],&ptl[k+1],(i-k)*sizeof(PaletteTableList));
 		divide_palette_area(&p,&ptl[i-1],&ptl[i],table);
 		i++;
 	}
@@ -285,11 +284,11 @@ void bitmap_expand(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	length=bm_header_bytes(bmih0);
 	p=(guint8 *)bmih0+length;
 	q=(guint8 *)bmih1+length;
-	memcpy(bmih1,bmih0,length);
-	bmih_set_compression(bmih1,BI_RGB);
+	g_memmove(bmih1,bmih0,length);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_size_image(bmih1,bm_image_bytes(bmih1));
 	length=bm_line_bytes(bmih0);
-	if (bmih_get_compression(bmih0)==BI_RLE8)
+	if (bmih_get_compression (bmih0) == BI_COMP_RLE8)
 		while (*p!=0 || *(p+1)!=1)
 			if (*p==0) {
 				p++;
@@ -399,7 +398,7 @@ void bitmap_approx_1(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	bmih_set_height(bmih1,bmih_get_height(bmih0));
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,1);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_size_image(bmih1,bm_image_bytes(bmih1));
@@ -459,7 +458,7 @@ void bitmap_approx_4(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	bmih_set_height(bmih1,bmih_get_height(bmih0));
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,4);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_size_image(bmih1,bm_image_bytes(bmih1));
@@ -519,7 +518,7 @@ void bitmap_approx_8(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	bmih_set_height(bmih1,bmih_get_height(bmih0));
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,8);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_size_image(bmih1,bm_image_bytes(bmih1));
@@ -582,7 +581,7 @@ void bitmap_diffuse_1(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	bmih_set_height(bmih1,bmih_get_height(bmih0));
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,1);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_size_image(bmih1,bm_image_bytes(bmih1));
@@ -592,8 +591,7 @@ void bitmap_diffuse_1(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	length1=bm_line_bytes(bmih1);
 	p=(guint8 *)bmih0+bm_header_bytes(bmih0);
 	q=(guint8 *)bmih1+bm_header_bytes(bmih1);
-	buffer=g_malloc(bmih_get_width(bmih0)*sizeof(gshort)*3);
-	memset(buffer,0,bmih_get_width(bmih0)*sizeof(gshort)*3);
+	buffer=g_malloc0(bmih_get_width(bmih0)*sizeof(gshort)*3);
 	for (i=0;i<bmih_get_height(bmih0);i++) {
 		next_blue=next_green=next_red
 								=diagonal_blue=diagonal_green=diagonal_red=0;
@@ -662,7 +660,7 @@ void bitmap_diffuse_4(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	bmih_set_height(bmih1,bmih_get_height(bmih0));
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,4);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_size_image(bmih1,bm_image_bytes(bmih1));
@@ -672,8 +670,7 @@ void bitmap_diffuse_4(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	length1=bm_line_bytes(bmih1);
 	p=(guint8 *)bmih0+bm_header_bytes(bmih0);
 	q=(guint8 *)bmih1+bm_header_bytes(bmih1);
-	buffer=g_malloc(bmih_get_width(bmih0)*sizeof(gshort)*3);
-	memset(buffer,0,bmih_get_width(bmih0)*sizeof(gshort)*3);
+	buffer=g_malloc0(bmih_get_width(bmih0)*sizeof(gshort)*3);
 	for (i=0;i<bmih_get_height(bmih0);i++) {
 		next_blue=next_green=next_red
 								=diagonal_blue=diagonal_green=diagonal_red=0;
@@ -742,7 +739,7 @@ void bitmap_diffuse_8(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	bmih_set_height(bmih1,bmih_get_height(bmih0));
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,8);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_size_image(bmih1,bm_image_bytes(bmih1));
@@ -752,8 +749,7 @@ void bitmap_diffuse_8(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	length1=bm_line_bytes(bmih1);
 	p=(guint8 *)bmih0+bm_header_bytes(bmih0);
 	q=(guint8 *)bmih1+bm_header_bytes(bmih1);
-	buffer=g_malloc(bmih_get_width(bmih0)*sizeof(gshort)*3);
-	memset(buffer,0,bmih_get_width(bmih0)*sizeof(gshort)*3);
+	buffer=g_malloc0(bmih_get_width(bmih0)*sizeof(gshort)*3);
 	for (i=0;i<bmih_get_height(bmih0);i++) {
 		next_blue=next_green=next_red
 								=diagonal_blue=diagonal_green=diagonal_red=0;
@@ -817,7 +813,7 @@ void bitmap_order_1(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	bmih_set_height(bmih1,bmih_get_height(bmih0));
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,1);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_size_image(bmih1,bm_image_bytes(bmih1));
@@ -852,7 +848,7 @@ void bitmap_order_4(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	bmih_set_height(bmih1,bmih_get_height(bmih0));
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,4);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_size_image(bmih1,bm_image_bytes(bmih1));
@@ -904,7 +900,7 @@ void bitmap_order_8(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	bmih_set_height(bmih1,bmih_get_height(bmih0));
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,8);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_size_image(bmih1,bm_image_bytes(bmih1));
@@ -953,7 +949,7 @@ void bitmap_convert_16(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	bmih_set_height(bmih1,bmih_get_height(bmih0));
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,16);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_color_used(bmih1,0);
@@ -989,7 +985,7 @@ void bitmap_convert_24(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	bmih_set_height(bmih1,bmih_get_height(bmih0));
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,24);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_color_used(bmih1,0);
@@ -1000,7 +996,7 @@ void bitmap_convert_24(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	p=(guint8 *)bmih0+bm_header_bytes(bmih0);
 	q=(guint8 *)bmih1+bm_header_bytes(bmih1);
 	if (bmih_get_bit_count(bmih0)==16 || bmih_get_bit_count(bmih0)==32) {
-		if (bmih_get_compression(bmih0)==BI_RGB)
+		if (bmih_get_compression (bmih0) == BI_COMP_RGB)
 			if (bmih_get_bit_count(bmih0)==16) {
 				mask[0]=0x001f;
 				mask[1]=0x03e0;
@@ -1076,7 +1072,7 @@ void bitmap_convert_24(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 			}
 			break;
 		case 24:
-			memcpy(q,p,bm_image_bytes(bmih0));
+			g_memmove(q,p,bm_image_bytes(bmih0));
 			break;
 		case 32:
 			for (i=0;i<bmih_get_height(bmih0);i++) {
@@ -1120,7 +1116,7 @@ void bitmap_convert_24_with_bgcolor(BitmapInfoHeader *bmih0,
 	bmih_set_height(bmih1,bmih_get_height(bmih0));
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,24);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_color_used(bmih1,0);
@@ -1157,7 +1153,7 @@ void bitmap_convert_32(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	bmih_set_height(bmih1,bmih_get_height(bmih0));
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,32);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_color_used(bmih1,0);
@@ -1168,7 +1164,7 @@ void bitmap_convert_32(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	p=(guint8 *)bmih0+bm_header_bytes(bmih0);
 	q=(guint8 *)bmih1+bm_header_bytes(bmih1);
 	if (bmih_get_bit_count(bmih0)==16 || bmih_get_bit_count(bmih0)==32) {
-		if (bmih_get_compression(bmih0)==BI_RGB)
+		if (bmih_get_compression (bmih0) == BI_COMP_RGB)
 			if (bmih_get_bit_count(bmih0)==16) {
 				mask[0]=0x001f;
 				mask[1]=0x03e0;
@@ -1260,8 +1256,8 @@ void bitmap_convert_32(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 			}
 			break;
 		case 32:
-			if (bmih_get_compression(bmih0)==BI_RGB)
-				memcpy(q,p,bm_image_bytes(bmih0));
+			if (bmih_get_compression (bmih0) == BI_COMP_RGB)
+				g_memmove(q,p,bm_image_bytes(bmih0));
 			else
 				for (i=0;i<bmih_get_height(bmih0);i++) {
 					for (j=0;j<bmih_get_width(bmih0);j++)
@@ -1301,7 +1297,7 @@ void bitmap_zoom_1(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
     bmih_set_size(bmih1,BMIH_SIZE);
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,1);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_color_used(bmih1,bmih_get_color_used(bmih0));
@@ -1311,7 +1307,7 @@ void bitmap_zoom_1(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	length1=bm_line_bytes(bmih1);
 	src=(guint8 *)bmih0+bm_header_bytes(bmih0);
 	dst=(guint8 *)bmih1+bm_header_bytes(bmih1);
-	memset(dst,0,bmih_get_height(bmih1)*length1);
+	g_memset(dst,0,bmih_get_height(bmih1)*length1);
 	for (y1=0;y1<bmih_get_height(bmih1);y1++) {
 		y0=y1*bmih_get_height(bmih0)/bmih_get_height(bmih1);
 		for (x1=0;x1<bmih_get_width(bmih1);x1++) {
@@ -1334,7 +1330,7 @@ void bitmap_zoom_4(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
     bmih_set_size(bmih1,BMIH_SIZE);
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,4);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_color_used(bmih1,bmih_get_color_used(bmih0));
@@ -1344,7 +1340,7 @@ void bitmap_zoom_4(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
 	length1=bm_line_bytes(bmih1);
 	src=(guint8 *)bmih0+bm_header_bytes(bmih0);
 	dst=(guint8 *)bmih1+bm_header_bytes(bmih1);
-	memset(dst,0,bmih_get_height(bmih1)*length1);
+	g_memset(dst,0,bmih_get_height(bmih1)*length1);
 	for (y1=0;y1<bmih_get_height(bmih1);y1++) {
 		y0=y1*bmih_get_height(bmih0)/bmih_get_height(bmih1);
 		for (x1=0;x1<bmih_get_width(bmih1);x1++) {
@@ -1367,7 +1363,7 @@ void bitmap_zoom_8(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
     bmih_set_size(bmih1,BMIH_SIZE);
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,8);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_color_used(bmih1,bmih_get_color_used(bmih0));
@@ -1398,7 +1394,7 @@ void bitmap_zoom_16(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
     bmih_set_size(bmih1,BMIH_SIZE);
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,16);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_color_used(bmih1,bmih_get_color_used(bmih0));
@@ -1429,7 +1425,7 @@ void bitmap_zoom_24(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
     bmih_set_size(bmih1,BMIH_SIZE);
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,24);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_color_used(bmih1,bmih_get_color_used(bmih0));
@@ -1462,7 +1458,7 @@ void bitmap_zoom_32(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1)
     bmih_set_size(bmih1,BMIH_SIZE);
 	bmih_set_planes(bmih1,1);
 	bmih_set_bit_count(bmih1,32);
-	bmih_set_compression(bmih1,BI_RGB);
+	bmih_set_compression (bmih1, BI_COMP_RGB);
 	bmih_set_x_pixels_per_meter(bmih1,bmih_get_x_pixels_per_meter(bmih0));
 	bmih_set_y_pixels_per_meter(bmih1,bmih_get_y_pixels_per_meter(bmih0));
 	bmih_set_color_used(bmih1,bmih_get_color_used(bmih0));
@@ -1549,7 +1545,7 @@ void bitmap_overlay_32(BitmapInfoHeader *bmih0,BitmapInfoHeader *bmih1,
 		q1=(guint32 *)((guint8 *)bmih1+bm_header_bytes(bmih1));
 		width*=sizeof(guint32);
 		for (y=0;y<height;y++)
-			memcpy(q0+(under_leng-y)*bmih_get_width(bmih0)+x_under,
+			g_memmove(q0+(under_leng-y)*bmih_get_width(bmih0)+x_under,
 						q1+(over_leng-y)*bmih_get_width(bmih1)+x_over,width);
 	}
 }
